/*====================================================================*
 -  Copyright (C) 2001 Leptonica.  All rights reserved.
 -  This software is distributed in the hope that it will be
 -  useful, but with NO WARRANTY OF ANY KIND.
 -  No author or distributor accepts responsibility to anyone for the
 -  consequences of using this software, or for whether it serves any
 -  particular purpose or works at all, unless he or she says so in
 -  writing.  Everyone is granted permission to copy, modify and
 -  redistribute this source code, for commercial or non-commercial
 -  purposes, with the following restrictions: (1) the origin of this
 -  source code must not be misrepresented; (2) modified versions must
 -  be plainly marked as such; and (3) this notice may not be removed
 -  or altered from any source or modified source distribution.
 *====================================================================*/


/*
 *     stack.h
 *
 *          Generic stack
 *
 *          The stack is an array of void * ptrs, onto which
 *          objects can be stored.  At any time, the number of
 *          stored objects is stack->n.  The object at the bottom
 *          of the stack is at array[0]; the object at the top of
 *          the stack is at array[n-1].  New objects are added
 *          to the top of the stack; i.e., the first available
 *          location, which is at array[n].  The stack is expanded
 *          by the usual methods as needed.  Objects are removed
 *          from the top of the stack.  When an attempt is made
 *          to remove an object from an empty stack, the result
 *          is null.
 *
 *          The auxiliary stack can be used to store and remove
 *          objects for re-use.  It must be created by a separate
 *          call to stackCreate().  stackDestroy() checks for
 *          it and removes it.
 */

#ifndef STACK_H_INCLUDED
#define STACK_H_INCLUDED


    /* note that array[n] is the first null ptr in the array */
struct Stack
{
    INT32          nalloc;       /* size of ptr array */
    INT32          n;            /* number of stored elements */
    void         **array;        /* ptr array */
    struct Stack  *auxstack;     /* auxiliary stack */
};
typedef struct Stack  STACK;



#endif /* STACK_H_INCLUDED */
