package ca.bcgsc.rwong.LRUI;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.Reader;
import java.io.StreamTokenizer;
import java.util.ArrayList;

/**
 * class to read a lanes file and extract all the data into xVals and yVals
 * @author rwong
 *
 */
public class LanesReader {

	/**
	 * xVals of all nodes
	 */
	double[] xVals;
	/**
	 * yVals of all nodes	
	 */
	double[][] yVals;
	
	/**
	 * initialize empty lanesReader
	 *
	 */
	public LanesReader(){
		xVals = new double[10];
		yVals = new double[10][100];
	}
	
	/**
	 * initialize lanesReader with a given file paht
	 * lanesReader will read and parse the file
	 * @param inFileName path to the source lanes file
	 * @throws IOException
	 */
	public LanesReader(String inFileName) throws IOException{		

		Reader r = new BufferedReader(new FileReader(inFileName));
		StreamTokenizer st = new StreamTokenizer(r);
		
		int zone=0;
		int row=0;
		ArrayList<Double> xInputs=new ArrayList<Double>();
		ArrayList<ArrayList<Double>>yInputs=new ArrayList<ArrayList<Double>>();
		ArrayList <Double>tempList=new ArrayList<Double>();
		boolean zoneNum= false;
		boolean xPosNum = false;
					
		// parsing lanes file into ArrayList
		st.eolIsSignificant(true);
		try {
			while(st.nextToken()!=StreamTokenizer.TT_EOF){
				if(st.ttype==StreamTokenizer.TT_WORD){

					if(st.sval.equals("z")){
						zoneNum = true;
					}else if (st.sval.equals("x")){
						xPosNum = true;
					}
				} else if(st.ttype==StreamTokenizer.TT_NUMBER){
					if(zoneNum){ //number following z= , node number, do nothing
						zoneNum=false;
					}else if (xPosNum){ //number following x=, node x position
						xPosNum=false;
						xInputs.add(st.nval);
						//add a new list and keep handle for putting in data
						yInputs.add(new ArrayList<Double>());
						tempList=(ArrayList<Double>) yInputs.get(zone);
						zone++;
					}else{ //otherwise, y position
						tempList.add(st.nval);	
					}
				}
			}
		} catch (IOException e) {
			e.printStackTrace();
		}
		
		//transfer to double arrays
		tempList=(ArrayList<Double>) yInputs.get(0);
		xVals = new double[xInputs.size()];
		yVals = new double[yInputs.size()][tempList.size()];
		
		for(zone=0; zone<xVals.length; zone++){
			xVals[zone] = (Double) xInputs.get(zone);
			tempList = (ArrayList<Double>) yInputs.get(zone);
			for(row=0; row<yVals[0].length; row++){
				yVals[zone][row]=(Double) tempList.get(row);
			}
		}		
	}
}
