package ca.bcgsc.rwong.LRUI;

import java.awt.geom.Line2D;
import java.awt.geom.Rectangle2D;


/**
 * represents a node with their true x, y position, status as marker, 
 * handles to the lines connected to it and on screen presentation
 * @author rwong
 *
 */
public class Node {
	
	/**default values to be overwritten by value in GelSettings*/
	private static double rectSize=10;
	private static double strokeSize=10;
	/**static variable all nodes have the same scale factor and it is changed
	 * as the scale changes
	 */
	private static double xScaleFactor=1;
	private static double yScaleFactor=1;
	
	private int row;
	private int zone;
	private double x;
	private double y;
	boolean IsMarker=false;
	Rectangle2D rect;
	Line2D lineTo;
	Line2D lineFrom;

	/**
	 * start a new node, creating a new line to both sides
	 * @param zone zone of the node
	 * @param row row of the node
	 * @param isMarker rather the node is marker
	 * @param x x position of the node
	 * @param y y position of the node
	 */
	public Node(int zone, int row, boolean isMarker, double x, double y){
		this.row = row;
		this.IsMarker=isMarker;

		this.zone = zone;
		this.x=x;
		this.y=y;
		
		//working out on screen represenation
		double scaledx = getScaledX();
		double scaledy = getScaledY();
		double scaledRectSize = Node.getScaledRectSize();
		rect = new Rectangle2D.Double(scaledx-scaledRectSize/2, scaledy-scaledRectSize/2, scaledRectSize, scaledRectSize);
		
		lineTo = new Line2D.Double(0,0,scaledx, scaledy);
		lineFrom = new Line2D.Double(scaledx, scaledy,0,0);

	}
	
	/**
	 * start a new node, creating a new line only towards the right side
	 * @param zone zone of the node
	 * @param row row of the node
	 * @param isMarker rather the node is marker
	 * @param x x position of the node
	 * @param y y position of the node
	 * @param lineTo handle to the line leading from the last node
	 */
	public Node(int zone, int row, boolean isMarker, double x, double y, Line2D lineTo){
		this(zone, row, isMarker, x, y);
		this.lineTo = lineTo;
		
		//peg end of given line to center of this node
		double scaledx = getScaledX();
		double scaledy = getScaledY();
		lineTo.setLine(lineTo.getX1(),lineTo.getY1(), scaledx, scaledy);
		
	}
	
	/**
	 * start a new node, creating no new lines
	 * @param zone zone of the node
	 * @param row row of the node
	 * @param isMarker rather the node is marker
	 * @param x x position of the node
	 * @param y y position of the node
	 * @param lineTo handle to the line leading from the last node
	 * @param lineFrom handle to the line leading to the next node
	 */
	public Node(int zone, int row, boolean isMarker, double x, double y, Line2D lineTo, Line2D lineFrom){
		this(zone, row, isMarker, x, y, lineTo);
		this.lineFrom = lineFrom;
		
		//peg end of given line to center of this node
		double scaledx = getScaledX();
		double scaledy = getScaledY();

		lineFrom.setLine(scaledx, scaledy, lineFrom.getX2(),lineFrom.getY2());
	}

	/**
	 * resetting location, working out the true x and y
	 * @param scaledx new on screen x location of the node
	 * @param scaledy new on screen y location of the node
	 */
	public void setLocation(double scaledx, double scaledy){
		x=scaledx/Node.xScaleFactor;
		y=scaledy/Node.yScaleFactor;
		double scaledRectSize = getScaledRectSize();
		//reset the rectangle and lines
		rect = new Rectangle2D.Double(scaledx-scaledRectSize/2, scaledy-scaledRectSize/2, scaledRectSize, scaledRectSize);
		lineTo.setLine(lineTo.getX1(),lineTo.getY1(), scaledx, scaledy);
		lineFrom.setLine(scaledx, scaledy, lineFrom.getX2(),lineFrom.getY2());
	}

	/**
	 * redraw the node
	 *
	 */
	public void redraw(){
		setLocation(getScaledX(),getScaledY());
	}
	
	/**
	 * @return on screen x location of the node
	 */
	public double getScaledX(){
		return x*Node.xScaleFactor;
	}
	/**
	 * @return on screen y location of the node
	 */
	public double getScaledY(){
		return y*Node.yScaleFactor;
	}
	
	/**
	 * @return true x location of the node
	 */
	public double getX(){
		return x;
	}
	/**
	 * @return true y location of the node
	 */
	public double getY(){
		return y;
	}
	
	/**
	 *the node is represented by a square, having dimension conforming to the smaller 
	 *zoom scale of the two dimensions 
	 * @return size of the rectangle to be drawn on screen
	 */
	public static double getScaledRectSize(){
		return Math.min(Node.rectSize*Node.yScaleFactor, Node.rectSize*Node.xScaleFactor);
	}
	public static void setRectSize(double size){
		Node.rectSize=size;
	}
	public static double getRectSize(){
		return Node.rectSize;
	}
	public static double getScaledStrokeSize(){
		return Node.strokeSize*Node.yScaleFactor;
	}
	public static void setStrokeSize(double size){
		Node.strokeSize=size;
	}
	public static double getStrokeSize(){
		return Node.strokeSize;
	}
	public static void setXScaleFactor(double scaleFactor){
		Node.xScaleFactor=scaleFactor;
	}
	public static void setYScaleFactor(double scaleFactor){
		Node.yScaleFactor=scaleFactor;
	}
	
	public int getZone(){return zone;}
	public int getRow(){return row;}
	

}
