package ca.bcgsc.rwong.LRUI;


import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JSpinner;
import javax.swing.JPanel;
import javax.swing.SpinnerModel;
import javax.swing.SpinnerNumberModel;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

/**panel to hold controls related to zooms 
 * as well as transparency setting
 * @author rwong
 *
 */ 
public class ZoomPanel extends JPanel implements ActionListener, ChangeListener{

	private static final long serialVersionUID = 1L;
	private LaneRulerFrame parentFrame;	
	private JSpinner xZoomSpinner;
	private JSpinner yZoomSpinner;
	private JButton zoomResetButton;
	private JButton zoomInButton;
	private JButton zoomOutButton;
    private JCheckBox transparencyBox;
	
    /**lower limit of zoom allowed*/
	final static double MINZOOM = 0.1;
    /**upper limit of zoom allowed*/
	final static double MAXZOOM = 5;
	
	public ZoomPanel(LaneRulerFrame parent){
		super(new FlowLayout(FlowLayout.LEFT));
		parentFrame = parent;
		
        zoomInButton = new JButton("+");
        zoomInButton.setVerticalTextPosition(JButton.CENTER);
        zoomInButton.setHorizontalTextPosition(JButton.CENTER);
        zoomInButton.setToolTipText("Click this to zoom in.");   
        zoomInButton.addActionListener(this);     
        
		
        zoomOutButton = new JButton("-");
        zoomOutButton.setVerticalTextPosition(JButton.CENTER);
        zoomOutButton.setHorizontalTextPosition(JButton.CENTER);
        zoomOutButton.setToolTipText("Click this to zoom out.");   
        zoomOutButton.addActionListener(this);    	
		
        SpinnerModel xModel = new SpinnerNumberModel(parentFrame.gelSettings.initXZoom, 0, 100, .2);
        xZoomSpinner = new JSpinner(xModel);
        xZoomSpinner.addChangeListener(this);
        
        SpinnerModel yModel = new SpinnerNumberModel(parentFrame.gelSettings.initYZoom, 0, 100, .2);
        yZoomSpinner = new JSpinner(yModel);
        yZoomSpinner.addChangeListener(this);      
	        
        zoomResetButton = new JButton("RESET");
        zoomResetButton.setVerticalTextPosition(JButton.CENTER);
        zoomResetButton.setHorizontalTextPosition(JButton.CENTER);
        zoomResetButton.setToolTipText("Click this to reset zoom.");   
        zoomResetButton.addActionListener(this);
        
        transparencyBox = new JCheckBox("Transparent Overlay", true);
        transparencyBox.setHorizontalTextPosition(JCheckBox.LEFT);
        transparencyBox.setName("transparency");
        transparencyBox.setToolTipText("enable/disable overlay of selected node");
        transparencyBox.addActionListener(parent.getGelPane().getAdjustPane());
        
        add(new JLabel("Zoom:"));
        add(zoomInButton);
        add(zoomOutButton);
        add(zoomResetButton);
        add(new JLabel("x:"));
        add(xZoomSpinner);
        add(new JLabel("y:"));
        add(yZoomSpinner);
        add(transparencyBox);
 	}
	
	/**
	 * update the scale as user changes the zoom settings using buttons
	 */
	public void actionPerformed(ActionEvent e) {
		double newXScale;
		double newYScale;
		if(e.getSource()==zoomResetButton){
			newXScale=parentFrame.gelSettings.initXZoom;
			newYScale=parentFrame.gelSettings.initYZoom;
			parentFrame.getGelPane().changeScale(newXScale, newYScale);
	        parentFrame.getScrollPane().revalidate();
	        parentFrame.getScrollPane().repaint();
	        xZoomSpinner.setValue(newXScale);
	        yZoomSpinner.setValue(newYScale);
		}
		if(e.getSource()==zoomInButton){
			newXScale=(Double) xZoomSpinner.getValue() * 1.3;
			newYScale=(Double) yZoomSpinner.getValue() * 1.3;
			parentFrame.getGelPane().changeScale(newXScale, newYScale);
	        parentFrame.getScrollPane().revalidate();
	        parentFrame.getScrollPane().repaint();
	        xZoomSpinner.setValue(newXScale);
	        yZoomSpinner.setValue(newYScale);
		}
		if(e.getSource()==zoomOutButton){
			newXScale=(Double) xZoomSpinner.getValue() * 0.7;
			newYScale=(Double) yZoomSpinner.getValue() * 0.7;
			parentFrame.getGelPane().changeScale(newXScale, newYScale);
	        parentFrame.getScrollPane().revalidate();
	        parentFrame.getScrollPane().repaint();
	        xZoomSpinner.setValue(newXScale);
	        yZoomSpinner.setValue(newYScale);
		}
		
	}
	/**
	 * update the scale as user changes the zoom settings using the spinners
	 */
	public void stateChanged(ChangeEvent e) {
		double newScale;

		if(e.getSource()==xZoomSpinner||e.getSource()==yZoomSpinner){
			JSpinner tempSpinner = (JSpinner) e.getSource();
			newScale=(Double) tempSpinner.getValue();
			if(newScale<MINZOOM){
				newScale=MINZOOM;
				tempSpinner.setValue(MINZOOM);
			}
			if(newScale>MAXZOOM){
				newScale=MAXZOOM;
				tempSpinner.setValue(MAXZOOM);
			}
			parentFrame.getGelPane().changeScale((Double)xZoomSpinner.getValue(), (Double)yZoomSpinner.getValue());
	        parentFrame.getScrollPane().revalidate();
	        parentFrame.getScrollPane().repaint();
		}
    }	
	
	/**
	 * grays out all the buttons 
	 *
	 */
	public void finish(){
		xZoomSpinner.setEnabled(false);
		yZoomSpinner.setEnabled(false);
		zoomResetButton.setEnabled(false);
		zoomInButton.setEnabled(false);
		zoomOutButton.setEnabled(false);
		transparencyBox.setEnabled(false);
	}
}

