/** @file border.h
 *\brief header file for border.c, contains function to find the outer most 
 *lanes by first finding the outer most marker lanes.  
 *
 *These are tested for similary and roughness before accepted.
 *Correlation and roughness code are also found here, which is also used for
 *result checking.
 */

#ifndef BORDER_H
#define BORDER_H

#include "allheaders.h"
#include "gelinfo.h"
#include "anacutoff.h"

/**\brief sigma value used for peak finding
 *@see specFindPeak()
 */
#define SIGMA_CUTOFF 4
/**\brief factor used to estimate the width of a peak based on generic spacing
 *@see specFindPeak()
 */
#define FWHM_FACTOR 5.0/9.0
/**\brief determines the number of zones to include in border finding*/
#define ZONE_PROJECTION_FACTOR 3
/**\brief factor used to calculate the tolerance we allow from the expected spacing between lanes*/
#define BORDERTOLERANCEFACTOR 0.4
/**\brief factor used to determine along lane (x) offset allowed for correlation calculation
 *@see correlation()
*/
#define OFFSETFACTOR 40

/**\brief finds the outer most lanes by extrapolating from the outermost marker lanes.*/
void findBorder (FILE *FLAGOUT_FILE, PIX *pixGel, INT32 **ZoneProjection, struct GelInfo *GelInfo, struct AnaCutoff *AnaCutoff, int *ToneAdjusted, int Verbose);
/**brief calculates the uncentered correlation between two rows in a PIX while allowing for a offset.*/
float correlation(PIX *pixGel, int row1, int row2, int start, int stop, int maxoffset);
/**\brief calculates a roughness measure in a row in a PIX, defined as the sum of the absolute difference between neighbouring points normalized by the dynamic range of the pix*/
float roughness (PIX *pixGel, int row, int start, int stop);
#endif
