/**@file checkresult.h
 *header file for checkresult.c, contain functions to check peak positon, 
 *marker correlation and roughness and subsequent correction
 */

#ifndef CHECKRESULT_H
#define CHECKRESULT_H

#include "allheaders.h"
#include "gelinfo.h"
#include "anacutoff.h"

/**\brief sigma value used for peak finding
 *@see specFindPeak()
 */
#define SIGMA_CUTOFF 4
/**\brief factor used to estimate the width of a peak based on generic spacing
 *@see specFindPeak()
 */
#define FWHM_FACTOR 5.0/9.0
/**\brief factor used to calculate the spacing tolerance to determine if a zone is marker-dominated or not*/
#define TOLERANCEFACTOR 3.0

/**\brief Check the number and location of interpolated lanes and markers */
void checkPeakPositions(FILE *ERROROUT_FILE, FILE *FLAGOUT_FILE, float **PeakPosition, float *Spacing, int Markerinc, struct GelInfo *GelInfo, struct AnaCutoff *AnaCutoff,int *num_interpolated_markers, int *num_interpolated_data, int *con_interpolated_markers, int *con_interpolated_data, int Verbose);

/**\brief checks the marker lane for roughness and correlation*/
void checkMarkers(FILE *ERROROUT_FILE, FILE *FLAGOUT_FILE, PIX *pixGelin, float **PeakPosition, float *NodePosition, int *ZoneID, struct GelInfo *GelInfo, struct AnaCutoff *AnaCutoff, float **MarkerCorrelation, float **MarkerRoughness, int Verbose);
/**\brief rematches a single node using the ZoneProjection provided, nodes interpolated based on the changed node will be re-interpolated*/
void matchSinglePeak(INT32 **ZoneProjection, struct GelInfo *GelInfo, float **PeakPosition, int zoneID, int laneID);
/**\brief markers nodes in segments with poor correlation (possibly noisy) are rematched using the filtered zone projection*/
int correctMarkers(FILE *FLAGOUT_FILE, INT32 **ZoneProjection, float **PeakPosition, struct GelInfo *GelInfo, struct AnaCutoff *AnaCutoff, float **MarkerCorrelation, int Verbose);
#endif
