/**@file findlanes.h
 *\brief header file for findlanes.c
 *holds the default gel parameters
 */
#ifndef FINDLANES_H
#define FINDLANES_H

/**\brief default number of expected lanes in the gel*/
#define DEFAULT_NLANES 121
/**\brief default marker period of the gel*/
#define DEFAULT_MARKERPERIOD 5
/**\brief location of first marker lane*/
#define DEFAULT_MARKEROFFSET 0
/**\brief distance from last marker to last lane*/
#define DEFAULT_LASTMARKEROFFSET 0
/**\brief default number of zones used for lane tracking*/
#define DEFAULT_NZONES 10
/**\brief default factor which determines how big the structural element is for closing*/
#define DEFAULT_SIZEFACTOR 10
/**\brief default position of the well edge (0=left, 1=top, 2=right, 3=bottom*/
#define DEFAULT_WELL_EDGE 0
/**\brief default fraction of the image that a gel is expected to take up*/
#define DEFAULT_GELSPANFACTOR 0.75
/**\brief default name of the image file*/
#define DEFAULT_GELNAME "image.tif"
/**\brief default project directory*/
#define DEFAULT_PROJECTDIR "."
/**\brief default minimum psize factor below which is peak is not accepted.*/
#define DEFAULT_MINPSIZEFACTOR 0.0
/**\brief dault name of the file to be used as a data dump*/
#define DEFAULT_FLAGOUT_NAME "LR_data.out"

/**\brief default name of the file to store error comment(s)*/
#define DEFAULT_ERROROUT_NAME "LR_error.out"
/**\brief dault name of the file to store no grow detection results*/
#define DEFAULT_NOGROW_NAME "LR_no_grow.out"
/**\brief default name for traces16 file*/
#define DEFAULT_TRACES_NAME "traces16_auto"
/**\brief default name for straightened image file*/
#define DEFAULT_OUTIMG_NAME "straight_img.png"
/**\brief default names for output lanes file*/
#define DEFAULT_LANES_NAME "lanes"
/**\brief default names for input lanes file*/
#define DEFAULT_IN_LANES_NAME "lanes"
/**\brief default name of the file to hold gel inspection parameters*/
#define DEFAULT_LIMS_NAME "LR_LIMS.out"

#include "allheaders.h"
/* include lepontica libraries*/
#include "gelinfo.h"
/* gelinfo struct*/
#include "anacutoff.h"
/* anacutoff struct*/
#include "readtiff.h"
#include "mapto8bits.h"
#include "medianfilter.h"
#include "zone.h"
#include "toneadjust.h"
#include "spacing.h"
#include "readlanes.h"
#include "position.h"
#include "diagnostic.h"
#include "border.h"
#include "node.h"
#include "checkresult.h"
#include "checknogrowths.h"
#include "noisedetect.h"

/**\brief for a given gel image tone adjust zones of low density using a point transformation with a monotonic Bezier curve*/
PIX *adjustTone(PIX *pixGel, INT32 **ZoneProjection, struct GelInfo *GelInfo, int *ZoneID, int *ToneAdjusted,  int Verbose);

#endif

