/**@file mapto8bits.c
 *\brief contains functino to map a 16 bit image to 8 bit and 
 *stretches its dymanic range to be full scale
 */
#include <stdio.h>
#include <stdlib.h>
#include "mapto8bits.h"

/**\brief linearly map a 16bit pix to an 8bit pix while maximizing the dynamic range of the image
 *
 *@param FLAGOUT_FILE writable file handle to data log file
 *@param pixGelRaw input 16 bit pix 
 *@param GelInfo holds various gel parameters
 *@param Verbose turn on text output to screen
 *@returns mapped 8 bits pix
 */
PIX *pixMapTo8bits (FILE *FLAGOUT_FILE, PIX *pixGelRaw, struct GelInfo *GelInfo, int Verbose) {

UINT8	dval;
UINT16	min16, max16, sval16;
INT32	i, j;
UINT32	word;
UINT32	*lines, *lined;
UINT32	*datas, *datad;
INT32	wpls, wpld;
FLOAT32	slope, intercept;
PIX	*pixGel8bits;

/*creating empty 8 bit pix same size as 16 bit pix*/
  if ((pixGel8bits = pixCreate(GelInfo->ImageWidth, GelInfo->ImageHeight, 8)) == NULL) {
    fprintf(stderr,"Cannot create 8 bit image!\n");
    exit(1);
  }
  /*getting pointers to pix data*/
  datas = pixGetData(pixGelRaw);
  wpls = pixGetWpl(pixGelRaw);
  datad = pixGetData(pixGel8bits);
  wpld = pixGetWpl(pixGel8bits);
  max16 = 0;
  min16 = 0xffff;
  /*find max and min of 16 bit image*/
  for (i = 0; i < GelInfo->ImageHeight; i++) {
    lines = datas + i * wpls;
    for (j = 0; j < wpls; j++) {
      word = *(lines + j);
      max16 = MAX(max16, word >> 16);
      max16 = MAX(max16, word & 0xffff);
      min16 = MIN(min16, word >> 16);
      min16 = MIN(min16, word & 0xffff);
    }
  }
  if (Verbose) fprintf(stderr, "Raw image: minimum = %d, maximum = %d\n",min16,max16);
  fprintf(FLAGOUT_FILE, "Raw image maximum:\t%d\nRaw image minimum:\t%d\n",min16, max16);

  /*mapping the image to 8 bit*/
  slope = 255 / (FLOAT32)(max16-min16);
  intercept = -1 * slope * min16;
  for (i = 0; i < GelInfo->ImageHeight; i++) {
    lines = datas + i * wpls;
    lined = datad + i * wpld;
    for (j = 0; j < GelInfo->ImageWidth; j++) {
      sval16 = GET_DATA_TWO_BYTES(lines, j);
      dval = (UINT8)(slope * (FLOAT32)sval16 + intercept);
      SET_DATA_BYTE(lined, j, dval);
     }
   }
    return pixGel8bits;
}

