/**@file position.h
 *\brief header file for position.c, contains functions for peak matching and curvature calculations and output*/

#ifndef POSITION_H
#define POSITION_H

#include "allheaders.h"
#include "gelinfo.h"

/**\brief sigma value used for peak finding
 *@see specFindPeak()
 */
#define SIGMA_CUTOFF 4
/**\brief factor used to estimate the width of a peak based on generic spacing
 *@see specFindPeak()
 */
#define FWHM_FACTOR 5.0/9.0
/**\brief factor used to determine the maximum difference between a peak and template in a match*/
#define TOLERANCEFACTOR 3.0
/**\brief factor used to determine the maximum allowed curvature of a node*/
#define MAXCURVATUREFACTOR 1.6

/**\brief Find peaks in ZoneProjections and match with nodes by closest distance to the template*/
int findPeakPosition (FILE *FLAGOUT_FILE, float **PeakPosition, INT32 **ZoneProjection, struct GelInfo *GelInfo, float *Spacing, float minpsizefactor, int Markerinc, int Verbose);
 /**\brief calculates curvature of a set of peak position and node position for all lanes and all zones*/
void writeCurvature(FILE *FLAGOUT_FILE, float **PeakPosition, float *NodePosition, struct GelInfo *GelInfo); 
/**\brief finds nodes showing high curvature and correct for them by forcing them to be in a straight line with their neighbours in neighbouring zones*/
int correctOutlierPeaks(float **PeakPosition, float *NodePosition, struct GelInfo *GelInfo, int Verbose); 
/**\brief compare each peak with the mean position of all other nodes in the lane
 *and smooth the overall results by applying a 3 lane x 3 zones  median filters to these differences */
void smoothPeaks(float **PeakPosition, struct GelInfo *GelInfo, int Verbose); 
/**\brief interpolate for any unplaced nodes (peak position == 0)*/
void fillEmpties(float *PeakPosition, struct GelInfo *GelInfo);

#endif
