/**@file readlanes.c
 *\brief read and parse lanes file in gel directory for node and peak positions 
 *for generation of traces16 without re-lanetracking*/

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "readlanes.h"

/**\brief reads in existing lanes file in project directory and use these values for peak and node positions
 *
 *@param PeakPosition holds y position of all nodes
 *@param inlanespath path to the source lanes file
 *@param NodePosition holds x position of nodes in each zone
 *@param GelInfo holds various gel parameters
*/
void readLanesFile(float **PeakPosition, char *inlanespath, float *NodePosition, struct GelInfo *GelInfo){

char	fullName[FILE_NAME_LEN];
FILE	*LANES;
int	nodeID, laneID;
char *strtemp;
 int linelen, curlane, curnode, num_line;

strtemp = calloc(linelen, sizeof(char));

  sprintf(fullName,"%s%s",GelInfo->ProjectDir, inlanespath);
  if ((LANES=fopen(fullName,"r"))==NULL) {
    fprintf(stderr,"Cannot open lanes file for reading\n");
    exit(1);
  }

  num_line =0;
  /*counting number of lines in file, not counting "StopPreData" line*/
  while((getline(&strtemp, &linelen, LANES))!= -1) {
    if (strtemp[0] != 83) /*S*/
      {
	num_line++;
      }
  }

  if (num_line!= GelInfo->NumberOfZones+3)
    {
      fprintf(stderr, "ERROR: Given lanes file has incorrect number of lines, %ilines expected, %i lines read\n", GelInfo->NumberOfZones+3, num_line);
      exit(1);
    }

  fseek(LANES, 0, SEEK_SET);

  /*take out first line*/
  getline(&strtemp, &linelen, LANES);

  for(curnode = 0; curnode < GelInfo->NumberOfZones+2; curnode++)
    {
      fscanf(LANES, "%*s %*2s%f", &NodePosition[curnode]);
      for (curlane = GelInfo->NumberOfLanes-1; curlane >= 0; curlane--)
	{
	  fscanf(LANES, "%f", &PeakPosition[curnode][curlane]);
	}
    }

  fclose(LANES);
}
