/**@file zone.h
 *\brief header file for zone.c, contains functions related to the 
 *initialization operations of zone boundary, nodes, and zoneprojection 
*/

#ifndef ZONE_H
#define ZONE_H

/**\brief factor used to determine the estimated position of the well*/
#define WELLWINDOWFACTOR 60
/**\brief factor used to determine the start of the maximum searching, to avoid areas outside of the gel*/
#define FINDMAXFACTOR 5
/**\brief the range of intensity used to set the bounds on the predata*/
#define PREDATAFACTOR 1.1
/**\brief the range of intensity used to set the bounds on the data after the second minimum*/
#define POSTDATAFACTOR 1.05
/**\brief number of lane spacing to include beyond the upper and lower border for the zone projection filtering*/
#define FIXFLATFACTOR 2.5
/**\brief number of rounds of median filtering done on the zoneprojection during filtering*/
#define SMOOTHROUNDS 2
/**\brief shift to fit INT32*/
#define SHIFTTOFIT32 8
/**\brief factor used to adjust the stop of the predata so that it is further from the first band*/
#define PREDATASTOPFACTOR 0.8
/**\brief if stopdata initially located at the end of the image, we step back this amount from the located edge of the gel*/
#define STOPDATASTEPBACKFACTOR 0.25
/**\brief unknown*/
#define MINZONESIZEFACTOR 4.0

#include "allheaders.h"
#include "gelinfo.h"

/**\brief Project to 1D (sum all pixel with same X) to establish StartPreData, StopPreData, StopData*/
void initZones (FILE *FLAGOUT_FILE, PIX *pixGel, struct GelInfo *GelInfo, int *ZoneID, int Verbose);
/**\brief integrate data horizontally in each zone, effectively getting a 1D profile for each zone*/
void projectZones (PIX *pixGel, INT32 **ZoneProjection, struct GelInfo *GelInfo, int *ZoneID);
/**\brief aggressive filtering of the zone projection using the generic spacing.*/
void filterZoneProjection (INT32 **ZoneProjection, struct GelInfo *GelInfo, float *Spacing); 
/**\brief set node position to be the center of data mass location of each zone*/
void setNodePositions (PIX *pixGel, struct GelInfo *GelInfo, int *ZoneID, float *NodePosition, int Verbose); 
#endif
